using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;

namespace UniformChildList
{

    public partial class Form1 : Form {

        BindingList<ParentObj> topList = new BindingList<ParentObj>();
        BindingList<ChildObj> childList = new BindingList<ChildObj>();
        
        public Form1() {
            InitializeComponent();
            SetupLists();
            
            grid.DataSource = topList;
            
            System.Drawing.Icon ico = new System.Drawing.Icon(Syncfusion.Windows.Forms.WinFormsUtils.FindFile("Icon", "sfgrid.ico"));
            this.Icon = ico;

            this.grid.TableOptions.ShowRecordPlusMinus = true;
            this.grid.NestedTableGroupOptions.ShowCaptionPlusMinus = false;
            this.grid.TopLevelGroupOptions.ShowAddNewRecordBeforeDetails = false;
            this.grid.TopLevelGroupOptions.ShowAddNewRecordAfterDetails = false;
            this.grid.NestedTableGroupOptions.ShowAddNewRecordBeforeDetails = false;
            this.grid.NestedTableGroupOptions.ShowAddNewRecordAfterDetails = false;
            this.grid.ChildGroupOptions.ShowAddNewRecordBeforeDetails = false;
            this.grid.ChildGroupOptions.ShowAddNewRecordAfterDetails = false;

            this.grid.Appearance.AlternateRecordFieldCell.BackColor = Color.FromArgb(255, 233, 176);
            this.grid.Appearance.AnyRecordFieldCell.TextColor = Color.FromArgb(0, 0, 102);

            GridRelationDescriptor relation = new GridRelationDescriptor();
            relation.RelationKind = RelationKind.UniformChildList;
            relation.MappingName = "Child";
            relation.Name = "Child";
            relation.ChildTableName = "ChildTable";
            grid.TableDescriptor.Relations.Add(relation);

            this.grid.ShowGroupDropArea = true;
            GridTable chiltTable = grid.GetTable("ChildTable");
            this.grid.AddGroupDropArea(chiltTable);
     //       chiltTable.TableDescriptor.GroupedColumns.Add("Field1");
            this.grid.Engine.SourceListSet.Add("MyGrandChildTable", GetGrandChildTable());
            

            GridRelationDescriptor childToGrandChildRelationDescriptor = new GridRelationDescriptor();
			childToGrandChildRelationDescriptor.ChildTableName = "MyGrandChildTable";  // same as SourceListSetEntry.Name for grandChhildTable (see below)            
            childToGrandChildRelationDescriptor.RelationKind = RelationKind.RelatedMasterDetails;
            childToGrandChildRelationDescriptor.RelationKeys.Add("parentID", "ChildID");

            chiltTable.TableDescriptor.Relations.Add(childToGrandChildRelationDescriptor);

            this.grid.TableOptions.GridVisualStyles = Syncfusion.Windows.Forms.GridVisualStyles.Office2007Blue;
            this.grid.TableOptions.GridLineBorder = new Syncfusion.Windows.Forms.Grid.GridBorder(GridBorderStyle.Solid, Color.FromArgb(208, 215, 229), GridBorderWeight.Thin);
            this.grid.TopLevelGroupOptions.ShowAddNewRecordBeforeDetails = false;
            this.grid.TopLevelGroupOptions.ShowCaption = false;
            this.grid.Appearance.AnyCell.Font.Facename = "Verdana";
            this.grid.Appearance.AnyCell.TextColor = Color.MidnightBlue;
            this.BackColor = Color.FromArgb(223, 227, 239);         
        }


        private DataTable GetGrandChildTable()
        {
            DataTable dt = new DataTable("GrandChildTable");

            dt.Columns.Add(new DataColumn("GrandChildID"));
            dt.Columns.Add(new DataColumn("Field1"));
            dt.Columns.Add(new DataColumn("Name")); //upper case C

            for (int i = 0; i < 25; i++)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i.ToString();
                dr[1] = string.Format("Name{0}", i);
                dr[2] = (i % 5).ToString();
                dt.Rows.Add(dr);
            }

            return dt;
        }

        [STAThread]
        static void Main()
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);
            Application.Run(new Form1());
        }

        Random r = new Random();
        private void SetupLists() 
        {

            for(int i =0;i<30;i++)
                childList.Add(new ChildObj(string.Format("Name{0}", i), string.Format("Desc{0}", r.Next(20)), r.Next(30)));

            for (int i = 0; i < 5; i++)
            {
                topList.Add(new ParentObj(string.Format("Name{0}",r.Next(5)),string.Format("Desc{0}",r.Next(15)),r.Next(20)));
                for (int j = i * 5; j < (i * 5) + 5; j++)
                    topList[i].Child.Add(childList[j]);
            }


        }
     
        private void Form1_Load(object sender, EventArgs e)
        {

        }       
    }
}